[Scummvm-cvs-logs] SF.net SVN: scummvm: [28864] scummvm/trunk/engines/saga/sndres.cpp

thebluegr at users.sourceforge.net thebluegr at users.sourceforge.net
Thu Sep 6 10:35:09 CEST 2007


Revision: 28864
          http://scummvm.svn.sourceforge.net/scummvm/?rev=28864&view=rev
Author:   thebluegr
Date:     2007-09-06 01:35:08 -0700 (Thu, 06 Sep 2007)

Log Message:
-----------
Simplified the check for the uncompressed sound data in patch files p2_a.iaf/p2_a.voc in ITE, when compressed sound files are used

Modified Paths:
--------------
    scummvm/trunk/engines/saga/sndres.cpp

Modified: scummvm/trunk/engines/saga/sndres.cpp
===================================================================
--- scummvm/trunk/engines/saga/sndres.cpp	2007-09-06 06:07:22 UTC (rev 28863)
+++ scummvm/trunk/engines/saga/sndres.cpp	2007-09-06 08:35:08 UTC (rev 28864)
@@ -183,10 +183,9 @@
 		} 
 		
 		bool uncompressedSound = false;
-		// If a patch file exists for sound resource 4 (used in ITE intro), don't treat this sound as compressed
-		if (_vm->getGameType() == GType_ITE && resourceId == 4 && 
-			(Common::File::exists("sound/p2_a.iaf") || Common::File::exists("sound/p2_a.voc") ||
-			 Common::File::exists("p2_a.iaf") || Common::File::exists("p2_a.voc")))
+		// If patch data exists for sound resource 4 (used in ITE intro), don't treat this sound as compressed
+		// Patch data for this resource is in file p2_a.iaf or p2_a.voc
+		if (_vm->getGameType() == GType_ITE && resourceId == 4 && context->table[resourceId].patchData != NULL)
 			uncompressedSound = true;
 
 		// FIXME: Currently, the SFX.RES file in IHNM cannot be compressed


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list